@@ -38,12 +38,14 @@ sub away {
     my $away_info = shift;
     $s->send($s->serverident,"306",$s->nick,"你已经被标记为离开");
     $s->is_away(1);
+    $s->set_mode("+a");
     $s->away_info($away_info);
 }
 sub back {
     my $s = shift;
     $s->send($s->serverident,"305",$s->nick,"你不再被标记为离开");
-    $s->is_away(0); 
+    $s->is_away(0);
+    $s->set_mode("-a");
     $s->away_info(undef);
 }
 sub quit{
@@ -61,6 +63,7 @@ sub ident{
 sub set_nick{
     my $s = shift;
     my $nick = shift;
+    $nick =~s/\s|\@|!//g;
     my $user = $s->search_user(nick=>$nick);
     if(defined $user and $user->id ne $s->id){
         if($user->is_virtual){
